"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _chalk = require("chalk");

var _chalk2 = _interopRequireDefault(_chalk);

var _yargs = require("yargs");

var _yargs2 = _interopRequireDefault(_yargs);

var _fix = require("./fix");

var _fix2 = _interopRequireDefault(_fix);

var _check = require("./check");

var _check2 = _interopRequireDefault(_check);

var _expandGlob = require("./expand-glob");

var _expandGlob2 = _interopRequireDefault(_expandGlob);

var _filterIgnored = require("./filter-ignored");

var _filterIgnored2 = _interopRequireDefault(_filterIgnored);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-console: 0 */

var cli = function cli(argv) {
  var yargsInstance = _yargs2.default
  // Fix
  .command("fix", "Fix one or more files").example("prettier-tslint fix file1.ts file2.ts", "Fix provided files").example("prettier-tslint fix '**/*.ts'", "Fix all .ts files")
  // Check
  .command("check", "List files that aren't formatted").example("prettier-tslint check '**/*.ts'", "List unformatted .ts files")
  // Meta
  .demandCommand(1, "Command not provided.").help();

  var args = yargsInstance.parse(argv);
  var command = args._[0];
  var patterns = args._.slice(1);

  switch (command) {
    case "fix":
      return patterns.forEach(fixFiles);
    case "check":
      return patterns.forEach(checkFiles);
    default:
      _yargs2.default.showHelp();
      console.error(`Unknown command: ${command}`);
  }
};

var fixFiles = function fixFiles(filePattern) {
  var files = (0, _filterIgnored2.default)((0, _expandGlob2.default)(filePattern));
  files.forEach(function (file) {
    var changed = !(0, _fix2.default)(file);
    console.log(changed ? file : _chalk2.default.gray(file));
  });
};

var checkFiles = function checkFiles(filePattern) {
  var files = (0, _filterIgnored2.default)((0, _expandGlob2.default)(filePattern));
  var invalid = files.filter(function (file) {
    return !(0, _check2.default)(file);
  });
  if (invalid.length) {
    process.exitCode = 1;
  }
  invalid.forEach(function (file) {
    return console.error(_chalk2.default.red.bold(file));
  });
};

exports.default = cli;